#' pRecipe: Precipitation R Recipes
#' 
#' pRecipe is an R package that facilitates the download, exploration, visualization, and analysis of multi-source precipitation data.
#'
#' @author \strong{Coded by:} Mijael Rodrigo Vargas Godoy \email{vargas_godoy@fzp.czu.cz}
#' @author \strong{Conceptual design by:} Mijael Rodrigo Vargas Godoy \email{vargas_godoy@fzp.czu.cz} and Yannis Markonis \email{markonis@fzp.czu.cz}
#' 
#' @references Vargas Godoy, M. R., & Markonis, Y. (2023). pRecipe: A global precipitation climatology toolbox and database. Environmental Modelling & Software, 165, 105711. \doi{10.1016/j.envsoft.2023.105711}
#' @keywords internal 
"_PACKAGE"